==> SHTOOLS-4.13.1.tar.gz: SHTOOLS-4.13.1/docs/pages/mydoc/contributors.md <==
---
title: "Contributors"
keywords: spherical harmonics software package, spherical harmonic transform, legendre functions, multitaper spectral analysis, fortran, Python, gravity, magnetic field
sidebar: mydoc_sidebar
permalink: contributors.html
summary:
toc: true
folder: mydoc
---

## Maintainers
* Mark Wieczorek / [MarkWieczorek](https://github.com/MarkWieczorek)

## Contributors
* Matthias Meschede / [MMesch](https://github.com/MMesch)
* Elliott Sales de Andrade / [QuLogic](https://github.com/QuLogic)
* Ilya Oshchepkov / [ioshchepkov](https://github.com/ioshchepkov)
* [xoviat](https://github.com/xoviat)
* Benda Xu / [heroxbd](https://github.com/heroxbd)
* Katrin Leinweber / [katrinleinweber](https://github.com/katrinleinweber)
* Andrew Walker / [andreww](https://github.com/andreww)
* Stefan Schröder / [Nasuyo](https://github.com/Nasuyo)
* Akihisa Hattori / [HattoriAkihisa](https://github.com/HattoriAkihisa)
* Aaryaman Vasishta / [jammm](https://github.com/jammm)
* Alex Kalinin / [alkalinin](https://github.com/alkalinin)
* Armin Corbin / [rainbowsend](https://github.com/rainbowsend)
* Tristan Brugere
* Erik Schnetter / [eschnett](https://github.com/eschnett)
* Martin Reinecke / [mreineck](https://github.com/mreineck)
* Juan Sierra / [jdsierral](https://github.com/jdsierral)
* Jonathon Kohler / [kohlerjl](https://github.com/kohlerjl)
* Pedro Lobo / [lobophf](https://github.com/lobophf)
* Pierre-Louis Phan / [pl-phan](https://github.com/pl-phan), [pphan-imcce](https://github.com/pphan-imcce)
* Dominik Kutra / [k-dominik](https://github.com/k-dominik)
* Orion Poplawski / [opoplawski](https://github.com/opoplawski)
* Adrien Broquet / [AB-Ares](https://github.com/AB-Ares)
* [EricAtORS](https://github.com/EricAtORS)
* David Minton / [profminton](https://github.com/profminton)
* Julia Maia / [jschmaia](https://github.com/jschmaia)
* David Shin / [spicydonkey](https://github.com/spicydonkey)
* Ethan Mentzer / [cometbeetle](https://github.com/cometbeetle)

==> SHTOOLS-4.14.1.tar.gz: SHTOOLS-4.14.1/docs/pages/mydoc/contributors.md <==
---
title: "Contributors"
keywords: spherical harmonics software package, spherical harmonic transform, legendre functions, multitaper spectral analysis, fortran, Python, gravity, magnetic field
sidebar: mydoc_sidebar
permalink: contributors.html
summary:
toc: true
folder: mydoc
---

## Maintainers
* Mark Wieczorek / [MarkWieczorek](https://github.com/MarkWieczorek)

## Contributors
* Matthias Meschede / [MMesch](https://github.com/MMesch)
* Elliott Sales de Andrade / [QuLogic](https://github.com/QuLogic)
* Ilya Oshchepkov / [ioshchepkov](https://github.com/ioshchepkov)
* [xoviat](https://github.com/xoviat)
* Benda Xu / [heroxbd](https://github.com/heroxbd)
* Katrin Leinweber / [katrinleinweber](https://github.com/katrinleinweber)
* Andrew Walker / [andreww](https://github.com/andreww)
* Stefan Schröder / [Nasuyo](https://github.com/Nasuyo)
* Akihisa Hattori / [HattoriAkihisa](https://github.com/HattoriAkihisa)
* Aaryaman Vasishta / [jammm](https://github.com/jammm)
* Alex Kalinin / [alkalinin](https://github.com/alkalinin)
* Armin Corbin / [rainbowsend](https://github.com/rainbowsend)
* Tristan Brugere
* Erik Schnetter / [eschnett](https://github.com/eschnett)
* Martin Reinecke / [mreineck](https://github.com/mreineck)
* Juan Sierra / [jdsierral](https://github.com/jdsierral)
* Jonathon Kohler / [kohlerjl](https://github.com/kohlerjl)
* Pedro Lobo / [lobophf](https://github.com/lobophf)
* Pierre-Louis Phan / [pl-phan](https://github.com/pl-phan), [pphan-imcce](https://github.com/pphan-imcce)
* Dominik Kutra / [k-dominik](https://github.com/k-dominik)
* Orion Poplawski / [opoplawski](https://github.com/opoplawski)
* Adrien Broquet / [AB-Ares](https://github.com/AB-Ares)
* [EricAtORS](https://github.com/EricAtORS)
* David Minton / [profminton](https://github.com/profminton)
* Julia Maia / [jschmaia](https://github.com/jschmaia)
* David Shin / [spicydonkey](https://github.com/spicydonkey)
* Ethan Mentzer / [cometbeetle](https://github.com/cometbeetle)
* Kristian Hansen / [KristianKvistIbsen](https://github.com/KristianKvistIbsen)
* Zain Eris Kamal / [Humboldt-Penguin](https://github.com/Humboldt-Penguin)
